#!/bin/sh -e
#
# NVIDIA Persistence Daemon Init Script
#
# Copyright (c) 2013 NVIDIA Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.
#
# This is a sample System V init script, designed to show how the NVIDIA
# Persistence Daemon can be started.
#
# This sample does not rely on any init system functions, to ensure the
# widest portability possible.
#
# chkconfig: 2345 99 01
# description: Starts and stops the NVIDIA Persistence Daemon
# processname: nvidia-persistenced
#
### BEGIN INIT INFO
# Provides:         nvidia-persistenced
# Required-Start:   $ALL
# Required-Stop:    $ALL
# Default-Start:    2 3 4 5
# Default-Stop:     0 1 6
# Description:      Starts and stops the NVIDIA Persistence Daemon
### END INIT INFO


NVPD=nvidia-persistenced
NVPD_BIN=/usr/bin/${NVPD}
NVPD_RUNTIME=/var/run/${NVPD}
NVPD_PIDFILE=${NVPD_RUNTIME}/${NVPD}.pid
NVPD_USER=__USER__

if [ -f ${NVPD_PIDFILE} ]; then
  read -r NVPD_PID < "${NVPD_PIDFILE}"
  # Remove stale runtime files
  if [ "${NVPD_PID}" ] && [ ! -d /proc/${NVPD_PID} ]; then
    unset NVPD_PID
    rm -rf "${NVPD_RUNTIME}"
  fi
fi

case "${1}" in
  start)
      echo "Starting NVIDIA Persistence Daemon"

      # Execute the daemon 
      ${NVPD_BIN} 
      ;;
  stop)
      echo "Stopping NVIDIA Persistence Daemon"

      # Stop the daemon - its PID should have been read in
      [ ! -z "${NVPD_PID}" ] && kill ${NVPD_PID} &> /dev/null
      ;;
  restart)
      $0 stop
      sleep 2
      $0 start
      ;;
  *) echo "usage: $0 {start|stop|restart}"
esac
exit 0
